NLSL: physcn Module Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- Modules List
- Module Members

Variables
physcn Module Reference

## Variables
double precision, parameter | ge =2.002 319 304 3737 D0
double precision, parameter | betae =927.400 899 D-23
double precision, parameter | hbar =1.054 571 596 D-27
double precision, parameter | gammae =1.760 859 794 D7
double precision, parameter | kb =1.380 6503 D-16

## Variable Documentation

double precision, parameter physcn::betae =927.400 899 D-23

Definition at line 20 of file physcn.f90.

double precision, parameter physcn::gammae =1.760 859 794 D7

Definition at line 20 of file physcn.f90.

double precision, parameter physcn::ge =2.002 319 304 3737 D0

Definition at line 20 of file physcn.f90.

double precision, parameter physcn::hbar =1.054 571 596 D-27

Definition at line 20 of file physcn.f90.

double precision, parameter physcn::kb =1.380 6503 D-16

Definition at line 20 of file physcn.f90.